@@ -488,7 +488,8 @@ class Mt3dSsm(Package):
             sys.stdout.write('loading ssm package file...\n')
 
         # Open file, if necessary
-        if not hasattr(f, 'read'):
+        openfile = not hasattr(f, 'read')
+        if openfile:
             filename = f
             f = open(filename, 'r')
 
@@ -701,6 +702,9 @@ class Mt3dSsm(Package):
                 current = current.view(np.recarray)
             stress_period_data[iper] = current
 
+        if openfile:
+            f.close()
+
         # set package unit number
         unitnumber = None
         filenames = [None]
